@@ -1,6 +1,6 @@
 package com.jayway.jsonpath;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class Issue_487 {
 
