@@ -1,12 +1,12 @@
 package com.jayway.jsonpath.internal.function;
 
 import com.jayway.jsonpath.JsonPath;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import java.io.IOException;
 
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 
 public class Issue629 {
@@ -15,8 +15,7 @@ public class Issue629 {
         try {
             JsonPath jsonPath = JsonPath.compile("$.A.B.C.D(");
             fail("accepted jsonpath with unclosed parentheses");
-        }
-        catch (Exception e) {
+        } catch (Exception e) {
             assertTrue(e.getMessage().startsWith("Arguments to function:"));
         }
     }
@@ -26,8 +25,7 @@ public class Issue629 {
         try {
             JsonPath jsonPath = JsonPath.compile("$.A.B.C.sum(D()");
             fail("accepted jsonpath with unclosed parentheses");
-        }
-        catch (Exception e) {
+        } catch (Exception e) {
             assertTrue(e.getMessage().startsWith("Arguments to function:"));
         }
     }
